// Copyright (C) 2003 Red Hat, Inc.
// Launcher that loads compiled Eclipse.

import java.io.*;
import java.net.*;
import java.lang.reflect.*;

public class gcjlauncher
{
  public static void die(String s)
  {
    System.err.println(s);
    System.exit(1);
  }

  // Usage: gcjlauncher args
  // Parses arguments like interpreter.
  // Remaining arguments are passed to Eclipse.
  public static void main(String[] args)
  {
    try
      {
	int i;
	File startup_so = null;

	for (i = 0; i < args.length; ++i)
	  {
	    if (args[i].charAt(0) != '-')
	      break;
	    if (args[i].equals("--"))
	      {
		++i;
		break;
	      }

	    if (args[i].startsWith("-D"))
	      {
		args[i] = args[i].substring(2);
		int equals = args[i].indexOf('=');
		String value;
		if (equals == -1)
		  value = "";
		else
		  {
		    value = args[i].substring(equals + 1);
		    args[i] = args[i].substring(0, equals);
		  }
		System.setProperty(args[i], value);
	      }
	    else if (args[i].startsWith("-X"))
	      {
		// Ignore.
	      }
	    else if (args[i].equals("-cp") || args[i].equals("-classpath"))
	      {
		++i;
		File f = new File(args[i]).getCanonicalFile();
		if (! f.exists())
		  die("couldn't find `" + f + "'");
		String name = f.getName();
		if (! name.endsWith(".jar"))
		  die(f + " not a jar file");
		name = "lib" + name.substring(0, name.length() - 4) + ".so";
		f = new File(f.getParent(), name);
		if (! f.exists())
		  die("couldn't find `" + f + "'");
		startup_so = f;
	      }
	    else
	      die("unrecognized option `" + args[i] + "'");
	  }

	if (startup_so == null)
	  die("didn't find startup .so file");

	String className = args[i++];

	URL startupURL = new URL("solib", "", startup_so.toString());
	URLClassLoader loader = new URLClassLoader(new URL[] { startupURL });

	String[] rest = new String[args.length - i];
	for (int j = i; j < args.length; ++j)
	  rest[j - i] = args[j];

	Class launcher = loader.loadClass(className);
	Method m = launcher.getMethod("main", new Class[] { String[].class });
	m.invoke(null, new Object[] { rest });
      }
    catch (Throwable _)
      {
	die("exception during startup: " + _);
      }
  }
}
